@@ -1,5 +1,4 @@
 package AnyEvent::BitTorrent;
-{ $AnyEvent::BitTorrent::VERSION = 'v0.2.5' }
 use AnyEvent;
 use AnyEvent::Handle;
 use AnyEvent::Socket;
@@ -14,6 +13,8 @@ use File::Path;
 use Net::BitTorrent::Protocol qw[:all];
 use Scalar::Util qw[/weak/];
 #
+our $VERSION = "1.0.0";
+#
 # XXX - These should be ro attributes w/o init args:
 my $block_size = 2**14;
 
@@ -93,10 +94,9 @@ has path => (is       => 'ro',
              isa      => $FILE,
              required => 1
 );
-has reserved => (is         => 'ro',
-                 lazy_build => 1,
-                 builder    => '_build_reserved',
-                 isa        => $RESERVED
+has reserved => (is      => 'ro',
+                 builder => '_build_reserved',
+                 isa     => $RESERVED
 );
 
 sub _build_reserved {
@@ -119,8 +119,8 @@ sub _build_peerid {
         'a20',
         (sprintf(
              '-AB%01d%01d%01d%1s-%7s%-5s',
-             ($AnyEvent::BitTorrent::VERSION =~ m[^v(\d+)\.(\d+)\.(\d+)]),
-             ($AnyEvent::BitTorrent::VERSION =~ m[[^\d\.^v]] ? 'U' : 'S'),
+             ($VERSION =~ m[^v?(\d+)\.(\d+)\.(\d+)]),
+             ($VERSION =~ m[[^\d\.^v]] ? 'U' : 'S'),
              (join '',
               map {
                   ['A' .. 'Z', 'a' .. 'z', 0 .. 9, qw[- . _ ~]]->[rand(66)]
@@ -812,53 +812,59 @@ sub _build_peer_timer {
                 last
                     if scalar(keys %{$s->peers}) > 100;    # XXX - Max peers
                 my $addr = splice @cache, rand $#cache, 1;
-                AE::log trace => 'Connecting to %s:%d', @$addr;
-                my $handle;
-                $handle = AnyEvent::Handle->new(
-                    connect    => $addr,
-                    on_prepare => sub {60},
-                    on_error   => sub {
-                        my ($hdl, $fatal, $msg) = @_;
-
-                        # XXX - callback
-                        AE::log
-                            error => 'Socket error: %s (Removing peer)',
-                            $msg;
-                        $s->_del_peer($hdl);
-                    },
-                    on_connect_error => sub {
-                        my ($hdl, $fatal, $msg) = @_;
-                        $s->_del_peer($hdl);
-
-                        # XXX - callback
-                        AE::log
-                            error => sprintf "%sfatal error (%s)\n",
-                            $fatal ? '' : 'non-',
-                            $msg // 'Connection timed out';
-                        return if !$fatal;
-                    },
-                    on_connect => sub {
-                        my ($h, $host, $port, $retry) = @_;
-                        AE::log
-                            trace => 'Connection established with %s:%d',
-                            $host, $port;
-                        $s->_add_peer($handle);
-                        $s->_send_handshake($handle);
-                    },
-                    on_eof => sub {
-                        my $h = shift;
-                        AE::log trace => 'EOF from peer';
-                        $s->_del_peer($h);
-                    },
-                    on_read => sub {
-                        $s->_on_read(@_);
-                    }
-                );
+                $s->_new_peer($addr);
             }
         }
     );
 }
 
+sub _new_peer {
+    my ($s, $addr) = @_;
+    AE::log trace => 'Connecting to %s:%d', @$addr;
+    my $handle;
+    $handle = AnyEvent::Handle->new(
+        connect    => $addr,
+        on_prepare => sub {60},
+        on_error   => sub {
+            my ($hdl, $fatal, $msg) = @_;
+
+            # XXX - callback
+            AE::log
+                error => 'Socket error: %s (Removing peer)',
+                $msg;
+            $s->_del_peer($hdl);
+        },
+        on_connect_error => sub {
+            my ($hdl, $fatal, $msg) = @_;
+            $s->_del_peer($hdl);
+
+            # XXX - callback
+            AE::log
+                error => sprintf "%sfatal error (%s)\n",
+                $fatal ? '' : 'non-',
+                $msg // 'Connection timed out';
+            return if !$fatal;
+        },
+        on_connect => sub {
+            my ($h, $host, $port, $retry) = @_;
+            AE::log
+                trace => 'Connection established with %s:%d',
+                $host, $port;
+            $s->_add_peer($handle);
+            $s->_send_handshake($handle);
+        },
+        on_eof => sub {
+            my $h = shift;
+            AE::log trace => 'EOF from peer';
+            $s->_del_peer($h);
+        },
+        on_read => sub {
+            $s->_on_read(@_);
+        }
+    );
+    return $handle;
+}
+
 sub _on_read_incoming {
     my ($s, $h) = @_;
     $h->rbuf // return;
